==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/RTFStringArray.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class RTFStringArray (  XlsObject, IRichTextString, IOptimizedUpdate) :
    """

    """

    def GetFont(self ,iPosition:int)->'IFont':
        """

        """
        
        GetDllLibXls().RTFStringArray_GetFont.argtypes=[c_void_p ,c_int]
        GetDllLibXls().RTFStringArray_GetFont.restype=c_void_p
        intPtr = GetDllLibXls().RTFStringArray_GetFont(self.Ptr, iPosition)
        ret = None if intPtr==None else XlsFont(intPtr)
        return ret



    def SetFont(self ,iStartPos:int,iEndPos:int,font:'IFont'):
        """

        """
        intPtrfont:c_void_p = font.Ptr

        GetDllLibXls().RTFStringArray_SetFont.argtypes=[c_void_p ,c_int,c_int,c_void_p]
        GetDllLibXls().RTFStringArray_SetFont(self.Ptr, iStartPos,iEndPos,intPtrfont)

    def ClearFormatting(self):
        """

        """
        GetDllLibXls().RTFStringArray_ClearFormatting.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_ClearFormatting(self.Ptr)


    def Append(self ,text:str,font:'IFont'):
        """

        """
        intPtrfont:c_void_p = font.Ptr

        GetDllLibXls().RTFStringArray_Append.argtypes=[c_void_p ,c_void_p,c_void_p]
        GetDllLibXls().RTFStringArray_Append(self.Ptr, text,intPtrfont)

    @property

    def Text(self)->str:
        """

        """
        GetDllLibXls().RTFStringArray_get_Text.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_Text.restype=c_void_p
        ret = PtrToStr(GetDllLibXls().RTFStringArray_get_Text(self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibXls().RTFStringArray_set_Text.argtypes=[c_void_p, c_wchar_p]
        GetDllLibXls().RTFStringArray_set_Text(self.Ptr, value)

    @property

    def RtfText(self)->str:
        """

        """
        GetDllLibXls().RTFStringArray_get_RtfText.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_RtfText.restype=c_void_p
        ret = PtrToStr(GetDllLibXls().RTFStringArray_get_RtfText(self.Ptr))
        return ret


    @property
    def IsFormatted(self)->bool:
        """

        """
        GetDllLibXls().RTFStringArray_get_IsFormatted.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_IsFormatted.restype=c_bool
        ret = GetDllLibXls().RTFStringArray_get_IsFormatted(self.Ptr)
        return ret

    def Clear(self):
        """

        """
        GetDllLibXls().RTFStringArray_Clear.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_Clear(self.Ptr)

    def BeginUpdate(self):
        """
<summary></summary>
        """
        GetDllLibXls().RTFStringArray_BeginUpdate.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_BeginUpdate(self.Ptr)

    def EndUpdate(self):
        """
<summary></summary>
        """
        GetDllLibXls().RTFStringArray_EndUpdate.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_EndUpdate(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/RTFStringArray.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class RTFStringArray (  XlsObject, IRichTextString, IOptimizedUpdate) :
    """

    """

    def GetFont(self ,iPosition:int)->'IFont':
        """

        """
        
        GetDllLibXls().RTFStringArray_GetFont.argtypes=[c_void_p ,c_int]
        GetDllLibXls().RTFStringArray_GetFont.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().RTFStringArray_GetFont, self.Ptr, iPosition)
        ret = None if intPtr==None else XlsFont(intPtr)
        return ret



    def SetFont(self ,iStartPos:int,iEndPos:int,font:'IFont'):
        """

        """
        intPtrfont:c_void_p = font.Ptr

        GetDllLibXls().RTFStringArray_SetFont.argtypes=[c_void_p ,c_int,c_int,c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_SetFont, self.Ptr, iStartPos,iEndPos,intPtrfont)

    def ClearFormatting(self):
        """

        """
        GetDllLibXls().RTFStringArray_ClearFormatting.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_ClearFormatting, self.Ptr)


    def Append(self ,text:str,font:'IFont'):
        """

        """
        intPtrfont:c_void_p = font.Ptr

        GetDllLibXls().RTFStringArray_Append.argtypes=[c_void_p ,c_void_p,c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_Append, self.Ptr, text,intPtrfont)

    @property

    def Text(self)->str:
        """

        """
        GetDllLibXls().RTFStringArray_get_Text.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_Text.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibXls().RTFStringArray_get_Text, self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibXls().RTFStringArray_set_Text.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibXls().RTFStringArray_set_Text, self.Ptr, value)

    @property

    def RtfText(self)->str:
        """

        """
        GetDllLibXls().RTFStringArray_get_RtfText.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_RtfText.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibXls().RTFStringArray_get_RtfText, self.Ptr))
        return ret


    @property
    def IsFormatted(self)->bool:
        """

        """
        GetDllLibXls().RTFStringArray_get_IsFormatted.argtypes=[c_void_p]
        GetDllLibXls().RTFStringArray_get_IsFormatted.restype=c_bool
        ret = CallCFunction(GetDllLibXls().RTFStringArray_get_IsFormatted, self.Ptr)
        return ret

    def Clear(self):
        """

        """
        GetDllLibXls().RTFStringArray_Clear.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_Clear, self.Ptr)

    def BeginUpdate(self):
        """
<summary></summary>
        """
        GetDllLibXls().RTFStringArray_BeginUpdate.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_BeginUpdate, self.Ptr)

    def EndUpdate(self):
        """
<summary></summary>
        """
        GetDllLibXls().RTFStringArray_EndUpdate.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().RTFStringArray_EndUpdate, self.Ptr)
